import viteAngular from '@analogjs/vite-plugin-angular';
import { enableProdMode } from '@angular/core';
function getRenderer() {
    return {
        name: '@analogjs/astro-angular',
        clientEntrypoint: '@analogjs/astro-angular/client.js',
        serverEntrypoint: '@analogjs/astro-angular/server.js',
    };
}
function getViteConfiguration(vite) {
    return {
        esbuild: {
            jsxDev: true,
        },
        optimizeDeps: {
            include: [
                '@angular/platform-browser',
                '@angular/core',
                '@analogjs/astro-angular/client.js',
            ],
            exclude: [
                '@angular/platform-server',
                '@analogjs/astro-angular/server.js',
            ],
        },
        plugins: [
            viteAngular(vite),
            {
                name: '@analogjs/astro-angular-platform-server',
                transform(code, id) {
                    if (id.includes('platform-server')) {
                        code = code.replace(/global\./g, 'globalThis.');
                        return {
                            code: code.replace('new xhr2.XMLHttpRequest', 'new (xhr2.default.XMLHttpRequest || xhr2.default)'),
                        };
                    }
                    return;
                },
            },
        ],
        ssr: {
            noExternal: ['@angular/**', '@analogjs/**'],
        },
    };
}
export default function (options) {
    process.env['ANALOG_ASTRO'] = 'true';
    return {
        name: '@analogjs/astro-angular',
        hooks: {
            'astro:config:setup': ({ addRenderer, config, isRestart, updateConfig, }) => {
                if (!isRestart && config.markdown?.syntaxHighlight === 'shiki') {
                    config.markdown.syntaxHighlight = 'prism';
                }
                addRenderer(getRenderer());
                updateConfig({
                    vite: getViteConfiguration(options?.vite),
                });
            },
            'astro:config:done': ({ config }) => {
                if ('markdown' in config &&
                    config.markdown.syntaxHighlight === 'shiki') {
                    console.warn(`[warning] The Angular integration doesn't support Shiki syntax highlighting in MDX files. Overriding with Prism.\n
To disable this warning, set the syntaxHighlight option in your astro.config.mjs mdx() integration to 'prism' or false.`);
                }
                if (process.env['NODE_ENV'] === 'production') {
                    enableProdMode();
                }
            },
        },
    };
}
//# sourceMappingURL=index.js.map